@@ -1,14 +1,12 @@
 from django.conf import settings
 
-#See http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.config.html for all settings
+# See http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.config.html
+# for all settings
 
 CKEDITOR_SETTINGS = getattr(settings, 'CKEDITOR_SETTINGS', {
     'language': '{{ language }}',
     'toolbar': 'CMS',
     'skin': 'moono',
-#    'stylesSet': [
-#        {'name': 'Custom Style', 'element': 'h3', 'styles': {'color': 'Blue'}}
-#    ],
     'toolbarCanCollapse': False,
 })
 
@@ -22,3 +20,4 @@ TEXT_SAVE_IMAGE_FUNCTION = getattr(settings, 'TEXT_SAVE_IMAGE_FUNCTION', save_fu
 TEXT_ADDITIONAL_TAGS = getattr(settings, 'TEXT_ADDITIONAL_TAGS', ())
 TEXT_ADDITIONAL_ATTRIBUTES = getattr(settings, 'TEXT_ADDITIONAL_ATTRIBUTES', ())
 TEXT_CKEDITOR_CONFIGURATION = getattr(settings, 'TEXT_CKEDITOR_CONFIGURATION', None)
+TEXT_HTML_SANITIZE = getattr(settings, 'TEXT_HTML_SANITIZE', True)
